@@ -1,6 +1,6 @@
 package List::AllUtils;
 {
-  $List::AllUtils::VERSION = '0.05';
+  $List::AllUtils::VERSION = '0.06';
 }
 BEGIN {
   $List::AllUtils::AUTHORITY = 'cpan:DROLSKY';
@@ -10,12 +10,16 @@ use strict;
 use warnings;
 
 # List::Util does not define an :all tag
-BEGIN
-{
+BEGIN {
     use List::Util 1.31 ();
-    List::Util->import( @List::Util::EXPORT_OK );
+    List::Util->import(@List::Util::EXPORT_OK);
+
+    use List::MoreUtils 0.28;
+
+    my %imported = map { $_ => 1 } @List::Util::EXPORT_OK;
+    List::MoreUtils->import( grep { !$imported{$_} }
+            @{ $List::MoreUtils::EXPORT_TAGS{':all'} } );
 }
-use List::MoreUtils 0.28 qw( :all );
 
 use base 'Exporter';
 
@@ -23,7 +27,6 @@ our @EXPORT_OK = ( @List::Util::EXPORT_OK, @List::MoreUtils::EXPORT_OK );
 
 our %EXPORT_TAGS = ( all => \@EXPORT_OK );
 
-
 1;
 
 # ABSTRACT: Combines List::Util and List::MoreUtils in one bite-sized package
@@ -38,7 +41,7 @@ List::AllUtils - Combines List::Util and List::MoreUtils in one bite-sized packa
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 SYNOPSIS
 
